@@ -170,6 +170,18 @@
 //! Without this feature, you can effectively only format primitive types
 //! (custom types can manually implement formatting with more difficulty).
 //!
+//! - `"rust_latest_stable"`(disabled by default):
+//! Enables all the `"rust_1_*"` features.
+//!
+//! - `"rust_1_64"`(disabled by default):
+//! Enables formatting of additional items that require Rust 1.64.0 to do so.
+//!
+//! - `"rust_1_82"`(disabled by default):
+//! Enables formatting of additional items that require Rust 1.82.0 to do so.
+//!
+//! - `"rust_1_88"`(disabled by default):
+//! Enables formatting of additional items that require Rust 1.88.0 to do so.
+//!
 //! - `"derive"`(disabled by default):
 //! Enables the [`PanicFmt` derive] macro.
 //!
@@ -222,11 +234,6 @@ mod panic_val;
 #[cfg(feature = "non_basic")]
 mod const_default;
 
-#[cfg(not(feature = "non_basic"))]
-mod utils;
-
-#[cfg(feature = "non_basic")]
-#[cfg_attr(feature = "docsrs", doc(cfg(feature = "non_basic")))]
 pub mod utils;
 
 #[cfg(all(test, not(feature = "test")))]
@@ -245,7 +252,13 @@ mod wrapper;
 
 mod fmt_impls {
     #[macro_use]
-    mod basic_fmt_impls;
+    pub(crate) mod basic_fmt_impls;
+
+    #[cfg(feature = "rust_1_64")]
+    mod rust_1_64_fmt_impls;
+
+    #[cfg(feature = "rust_1_82")]
+    mod rust_1_82_fmt_impls;
 
     #[macro_use]
     #[cfg(feature = "non_basic")]
@@ -259,6 +272,9 @@ mod fmt_impls {
 
     #[cfg(feature = "non_basic")]
     mod fmt_range;
+
+    #[cfg(all(feature = "non_basic", feature = "rust_1_88"))]
+    mod rust_1_88_nonbasic_fmt_impls;
 }
 
 pub use crate::{
@@ -293,10 +309,14 @@ pub mod __ {
 #[cfg(feature = "non_basic")]
 #[doc(hidden)]
 mod reexported_non_basic {
-    pub use core::option::Option::{self, None, Some};
+    pub use core::{mem::forget, option::Option, primitive::str, unreachable};
+
+    pub use typewit::MakeTypeWitness;
 
     pub use crate::{
+        concat_panic_::{compute_length, make_panic_string_unwrapped},
         const_default::ConstDefault,
+        macros::concat_macro::ConcatCmd,
         utils::{assert_flatten_panicvals_length, flatten_panicvals, panicvals_id},
     };
 
